//==============================================================================
// maze_test1.pov
// 02/03/2012
// Robert W. McGregor, www.mcgregorfineart.com
//------------------------------------------------------------------------------ 
// Description: Maze from just above ground level
//------------------------------------------------------------------------------ 
// Command-line: +w1280 +h720 +a0.2 +r3
//==============================================================================

#version 3.7;

#include "rwm_maze.inc"

default { 
   finish { ambient 0 specular 0 emission 0 diffuse 0.8 reflection 0 } 
   pigment { rgb 0.5 } 
}

//------------------------------------------------------------------------------ 
// Scene/Render Configuration 
//------------------------------------------------------------------------------ 

#declare Soft_Shadows = 1;  
#declare rez = 100; // 3..N 

global_settings { 
   assumed_gamma 1
   radiosity {
      brightness      1  
      recursion_limit 3
      pretrace_start  32/image_width
      pretrace_end    8/image_width
      count           200
      error_bound     0.25         
      nearest_count   10
      normal          off 
      always_sample   off
   }
}

//------------------------------------------------------------------------------ 
// Camera & Lights 
//------------------------------------------------------------------------------ 

#declare Cam_Loc = <-2, 15, -50>*0.75;

camera {  
   location Cam_Loc                                
   look_at  <-1, -12, 0>
   right x*image_width/image_height 
   angle 70
   rotate z*0.02 
}                     

#declare Light_Pos = <100, 100, -200>;
light_source { Light_Pos rgb 4 
   fade_power 3 
   fade_distance VDist(0, Light_Pos)/2
   #if (Soft_Shadows) 
      area_light <15, 0, 0>, <0, 0, 15>, 7, 7
      adaptive 2
      jitter
      orient circular
   #end
} 

//------------------------------------------------------------------------------ 
// Environment
//------------------------------------------------------------------------------ 

sphere { 0, 100000 hollow inverse
   pigment { image_map { exr "Landscape2_Small_Blurred" interpolate 2 map_type 1 }}
   rotate y*140
   finish { ambient 0.5 emission 0.5  diffuse 0}
}

//------------------------------------------------------------------------------ 
// Main
//------------------------------------------------------------------------------ 

#declare Maze = BuildMaze(rez, rez, 0.35)

object { Maze 
   pigment { bozo turbulence 0.5 scale 0.1 color_map {[0 rgb 0.4][1 rgb 0.6 ]} }
   normal { agate 0.05 scale 0.1 }
   finish { specular 0.25 roughness 0.02 reflection {0, 0.25 fresnel on} conserve_energy }
   interior { ior 1.5 }
   rotate -y*20
}

plane { y, -0.49 }

