//==============================================================================
// maze_test2.pov
// 02/05/2012
// Robert W. McGregor, www.mcgregorfineart.com
//------------------------------------------------------------------------------ 
// Description: Height field maze (using maze_test0.pov output as source image)  
//------------------------------------------------------------------------------ 
// Command-line: +w1280 +h720 +a0.2 +r3
//==============================================================================

#version 3.7;

#include "colors.inc"
#include "stones.inc"
#include "rwm_maze.inc"

default { 
   finish { ambient 0 specular 0 emission 0 diffuse 0.6 reflection 0 } 
   pigment { rgb 0.5 } 
}

//------------------------------------------------------------------------------ 
// Scene/Render Configuration 
//------------------------------------------------------------------------------ 

#declare Soft_Shadows = 1;  

#declare R = seed(1963);
                                                  
global_settings { 
   assumed_gamma 1
   radiosity {
      brightness      1  
      recursion_limit 3
      pretrace_start  32/image_width
      pretrace_end    8/image_width
      count           200
      error_bound     0.25         
      nearest_count   10
      normal          off 
      always_sample   off
   }
}

//------------------------------------------------------------------------------ 
// Camera & Lights 
//------------------------------------------------------------------------------ 

#declare Cam_Loc = <0, 20, -50>*0.85;

camera {  
   location Cam_Loc                                
   look_at  <-5.5, -8, 0>
   right x*image_width/image_height 
   angle 70
   rotate z*3 
}                     

#declare Light_Pos = <100, 100, -20>;
light_source { Light_Pos rgb 3 
   fade_power 4 
   fade_distance VDist(0, Light_Pos)/2
   #if (Soft_Shadows) 
      area_light <8, 0, 0>, <0, 0, 8>, 7, 7
      adaptive 2
      jitter
      orient circular
   #end
} 

//------------------------------------------------------------------------------ 
// Environment
//------------------------------------------------------------------------------ 

sphere { 0, 100000 hollow inverse
   pigment { image_map { exr "Landscape2_Small_Blurred" interpolate 2 map_type 1 }}
   rotate y*140
   finish { emission 1 diffuse 0 }
}

//------------------------------------------------------------------------------ 
// Main
//------------------------------------------------------------------------------ 

#local hf = height_field { png "maze_map.png" //"maze_test0.png" 
   translate -0.5
   scale y*0.01
}

object { hf 
   scale 200
   texture{T_Grnt27 scale <0.7, 0.99, 0.7> rotate <0, 0, 40> scale 0.75}
   texture{T_Grnt20a scale <1.9, 3, 0.5> rotate <0, 0, -50> scale 0.75}
   texture{T_Grnt12a scale <1, 1.3, 2> rotate <0, 0, 40> scale 0.75}
   texture{T_Crack1 scale <1, 0.6, 1> rotate <10, 0, -20> scale 0.75}                                          
   texture {  
      pigment {rgbt 1 filter 0.15}
      normal { 
         average
         normal_map {
            [1 granite 3 scale 5 ]
            [1 granite 2 scale 2 ]
            [0.5 granite 3 scale 0.35]
            [0.5 granite 5 scale 0.15]
            [0.35 granite 10 scale 0.05]
         }
         scale 0.35
      }
      finish { specular 0.2 roughness 0.05 reflection { 0, 0.25 fresnel on } conserve_energy }
   }                      
   interior { ior 2 }
}

